(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     19166,        566]
NotebookOptionsPosition[     16418,        512]
NotebookOutlinePosition[     16827,        528]
CellTagsIndexPosition[     16784,        525]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Extracting the Chiral Anomaly from \[Gamma]\[Pi] \[Rule] \[Pi]\[Pi]", \
"Title",
 CellChangeTimes->{{3.828601798295845*^9, 
  3.828601818956656*^9}},ExpressionUUID->"8ad34e71-88d7-4f28-8ed7-\
ebd604030e90"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
     "We", " ", "want", " ", "to", " ", "confirm", " ", "some", " ", 
      "calculations", " ", "from"}], " ", "<", 
     RowBox[{"https", ":"}]}], "//", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"arxiv", ".", "org"}], "/", "pdf"}], "/", 
      RowBox[{"1210.6793", ".", "pdf"}]}], ">"}]}], ";", " ", 
   RowBox[{
   "see", " ", "also", " ", "the", " ", "corresponding", " ", "handwritten", 
    " ", 
    RowBox[{"notes", "."}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.828533531273322*^9, 3.828533563419449*^9}, {
  3.8286018464635878`*^9, 3.828601865201414*^9}, {3.828673599975182*^9, 
  3.8286736114984713`*^9}},ExpressionUUID->"70e5b736-3567-4dce-a8f3-\
19388d2de41a"],

Cell[CellGroupData[{

Cell["Kinematics", "Section",
 CellChangeTimes->{{3.8286018316519623`*^9, 
  3.828601838252904*^9}},ExpressionUUID->"2ecdb72c-3019-40a1-9757-\
df618becdd4a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Useful", " ", "functions", " ", "and", " ", 
    RowBox[{"variables", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "=", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{"4", 
         SuperscriptBox["M\[Pi]", "2"]}], "s"]}]]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]", "[", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"], "+", 
      SuperscriptBox["z", "2"], "-", 
      RowBox[{"2", "x", " ", "y"}], "-", 
      RowBox[{"2", "x", " ", "z"}], "-", 
      RowBox[{"2", "y", " ", "z"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.827903905253169*^9, 3.827903929561741*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"af14b883-04d6-410b-a251-598c6e1295e9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Energies", " ", "and", " ", "momenta", " ", "of", " ", "the", " ", 
     "initial"}], "-", 
    RowBox[{"state", " ", 
     RowBox[{"particles", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      SqrtBox["s"], "\[Equal]", 
      RowBox[{
       SqrtBox[
        SuperscriptBox["p", "2"]], "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["M\[Pi]", "2"]}]]}]}], ",", "p"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pInitial", "=", 
     FractionBox[
      RowBox[{"s", "-", 
       SuperscriptBox["M\[Pi]", "2"]}], 
      RowBox[{"2", 
       SqrtBox["s"]}]]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      SuperscriptBox["pInitial", "2"]], "//", "PowerExpand"}], "//", 
    "Simplify"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["pInitial", "2"], "+", 
       SuperscriptBox["M\[Pi]", "2"]}]], "//", "PowerExpand"}], "//", 
    "Simplify"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E1Initial", "=", 
     FractionBox[
      RowBox[{"s", "-", 
       SuperscriptBox["M\[Pi]", "2"]}], 
      RowBox[{"2", 
       SqrtBox["s"]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E2Initial", "=", 
     FractionBox[
      RowBox[{"s", "+", 
       SuperscriptBox["M\[Pi]", "2"]}], 
      RowBox[{"2", 
       SqrtBox["s"]}]]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.828601722688232*^9, 3.828601739267557*^9}, {
  3.8286018793085012`*^9, 3.828601956248321*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"c146523d-1aa2-4e85-8562-a1974fb541ce"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["M\[Pi]", "2"], "-", "s"}], 
       RowBox[{"2", " ", 
        SqrtBox["s"]}]]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      FractionBox[
       RowBox[{"s", "-", 
        SuperscriptBox["M\[Pi]", "2"]}], 
       RowBox[{"2", " ", 
        SqrtBox["s"]}]]}], "}"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828601740098942*^9, {3.828601928310708*^9, 3.828601956643882*^9}, 
   3.828602144085458*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"88269c0a-d4be-4726-a637-1a4ec0c08373"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"s", "-", 
    SuperscriptBox["M\[Pi]", "2"]}], 
   RowBox[{"2", " ", 
    SqrtBox["s"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828601740098942*^9, {3.828601928310708*^9, 3.828601956643882*^9}, 
   3.828602144093093*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"e627f4ea-749a-434c-89b0-59b03c2f4044"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   SqrtBox[
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M\[Pi]", "2"], "+", "s"}], ")"}], "2"], "s"]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828601740098942*^9, {3.828601928310708*^9, 3.828601956643882*^9}, 
   3.828602144109105*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"74194e32-da86-464b-9c14-df88e4879ec2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Energies", " ", "and", " ", "momenta", " ", "of", " ", "the", " ", 
     "final"}], "-", 
    RowBox[{"state", " ", 
     RowBox[{"particles", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      SqrtBox["s"], "\[Equal]", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["M\[Pi]", "2"]}]], "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["M\[Pi]", "2"]}]]}]}], ",", "p"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pFinal", "=", 
     RowBox[{
      FractionBox[
       SqrtBox["s"], "2"], "\[Sigma]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["pFinal", "2"], "+", 
       SuperscriptBox["M\[Pi]", "2"]}]], "//", "PowerExpand"}], "//", 
    "Simplify"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EFinal", "=", 
     FractionBox[
      SqrtBox["s"], "2"]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.82860174596214*^9, 3.828601747827045*^9}, {
  3.8286019626775913`*^9, 3.828602074297209*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"fddd0fb5-a8c0-4ff8-9aed-b31b16df0efc"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SqrtBox[
        RowBox[{"s", "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["M\[Pi]", "2"]}]}]]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SqrtBox[
        RowBox[{"s", "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["M\[Pi]", "2"]}]}]]}]}], "}"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.82860197031487*^9, 3.828602008866127*^9}, {
   3.828602040515912*^9, 3.828602045639433*^9}, 3.8286021441660833`*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"be7a2283-f27a-45d6-9726-4dc2f1d43cea"],

Cell[BoxData[
 FormBox[
  FractionBox[
   SqrtBox["s"], "2"], TraditionalForm]], "Output",
 CellChangeTimes->{{3.82860197031487*^9, 3.828602008866127*^9}, {
   3.828602040515912*^9, 3.828602045639433*^9}, 3.828602144168602*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"25bfacd1-7712-4d6e-8206-6b7143536b22"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Taking the Angles into Account", "Subsection",
 CellChangeTimes->{{3.828534544891247*^9, 
  3.828534556199643*^9}},ExpressionUUID->"e0fb1f7c-0917-4659-bc3c-\
b45718e3fda4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"RESET", " ", 
    RowBox[{"KERNEL", "!"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"<<", "FeynCalc`"}]}]], "Input",
 CellLabel->"In[49]:=",ExpressionUUID->"d7d238ba-5ed5-440e-9a7f-449159f582f6"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\"FeynCalc is already loaded! If you are trying to reload \
FeynCalc or load FeynArts, TARCER, PHI, FeynHelpers or any other add-on, \
please restart the kernel.\"\>", "Text",
   StripOnInput->False,
   LineColor->RGBColor[1, 0, 0],
   FrontFaceColor->RGBColor[1, 0, 0],
   BackFaceColor->RGBColor[1, 0, 0],
   GraphicsColor->RGBColor[1, 0, 0],
   FontWeight->Bold,
   FontColor->RGBColor[1, 0, 0]], TraditionalForm]], "Print",
 CellChangeTimes->{3.828534565004195*^9, 3.828584654764347*^9, 
  3.828602151347189*^9, 3.8286859553027897`*^9},
 CellLabel->
  "During evaluation of \
In[49]:=",ExpressionUUID->"fad7513d-9742-4d91-9cb9-83c96ef9a646"],

Cell[BoxData[
 FormBox["$Aborted", TraditionalForm]], "Output",
 CellChangeTimes->{3.828685955316444*^9},
 CellLabel->"Out[49]=",ExpressionUUID->"7eac2cd7-81f4-4c9d-995b-977202e3f177"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "scalar", " ", "products", " ", "needed", " ", "to", " ", 
    "evaluate", " ", "the", " ", "below", " ", 
    RowBox[{"expressions", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "p1", "]"}], "=", 
     SuperscriptBox["M\[Pi]", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "p2", "]"}], "=", 
     SuperscriptBox["M\[Pi]", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "p0", "]"}], "=", 
     SuperscriptBox["M\[Pi]", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "q", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"p1", ",", "p2"}], "]"}], "=", 
     RowBox[{
      RowBox[{"E2Initial", "*", "EFinal"}], "-", 
      RowBox[{"pInitial", "*", "pFinal", "*", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"p1", ",", "p0"}], "]"}], "=", 
     RowBox[{
      RowBox[{"E2Initial", "*", "EFinal"}], "+", 
      RowBox[{"pInitial", "*", "pFinal", "*", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8285345708554373`*^9, 3.8285346219150343`*^9}, {
  3.8285352109812717`*^9, 3.828535211800798*^9}, {3.828535270567733*^9, 
  3.828535379952284*^9}, {3.828535410036374*^9, 3.828535426716085*^9}, {
  3.828536147038287*^9, 3.8285361521874723`*^9}, {3.828539666067862*^9, 
  3.8285396836235*^9}, {3.828539838938857*^9, 3.82853985057195*^9}, {
  3.8285399418483887`*^9, 3.828539949166913*^9}, {3.82854000584589*^9, 
  3.828540021150284*^9}, {3.828540157555131*^9, 3.828540161183444*^9}, {
  3.828540218230712*^9, 3.8285402560304413`*^9}, {3.8285404068387012`*^9, 
  3.8285404074808903`*^9}, {3.828602150128779*^9, 3.8286022230987577`*^9}, {
  3.828602291577331*^9, 3.828602303364221*^9}, {3.8286738806205606`*^9, 
  3.828673882437831*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"937264ca-8206-468c-a7ce-0bc80347d2f0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Mandelstam", " ", 
    RowBox[{"variables", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"t", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"SP", "[", 
       RowBox[{"p1", "-", "p2"}], "]"}], "//", "ScalarProductExpand"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"u", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"SP", "[", 
       RowBox[{"p1", "-", "p0"}], "]"}], "//", "ScalarProductExpand"}], "//", 
     "Simplify"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8286022274460697`*^9, 3.828602281401308*^9}, {
  3.8286023141064167`*^9, 3.828602325012052*^9}, {3.828602356996229*^9, 
  3.828602358599409*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"2b42fc16-a7af-4bdd-a002-05c09cef5851"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"cos", "(", "\[Theta]", ")"}], " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["M\[Pi]", "2"]}], "s"]}]], " ", 
      RowBox[{"(", 
       RowBox[{"s", "-", 
        SuperscriptBox["M\[Pi]", "2"]}], ")"}]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["M\[Pi]", "2"]}], "-", "s"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.828602252897462*^9, 3.828602325463689*^9}, 
   3.82860235883687*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"82137f75-9b27-40dd-b5ee-7d425b715997"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       RowBox[{"cos", "(", "\[Theta]", ")"}], " ", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"4", " ", 
           SuperscriptBox["M\[Pi]", "2"]}], "s"]}]], " ", 
       RowBox[{"(", 
        RowBox[{"s", "-", 
         SuperscriptBox["M\[Pi]", "2"]}], ")"}]}]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["M\[Pi]", "2"]}], "-", "s"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.828602252897462*^9, 3.828602325463689*^9}, 
   3.8286023588398533`*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"e6292c60-3202-4094-be0d-2ae129a57326"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dispersive Representations", "Section",
 CellChangeTimes->{{3.8287634917889977`*^9, 
  3.828763502074452*^9}},ExpressionUUID->"4ae5ba6b-30ef-4238-ae9b-\
d3ce1105f331"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Match", " ", "the", " ", "subtraction", " ", "constants", " ", "obtained",
     " ", "for", " ", "F", 
    RowBox[{"(", "s", ")"}], " ", "from", " ", "the", " ", "unitarity", " ", 
    "relation", " ", "to", " ", "the", " ", "ones", " ", "from", " ", "the", 
    " ", "Roy", " ", 
    RowBox[{"equations", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     FractionBox[
      SuperscriptBox["s", "2"], 
      RowBox[{"x", "-", "s"}]], ",", "s"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       FractionBox[
        SuperscriptBox["s", "2"], 
        RowBox[{"x", "-", "s"}]], ",", "s"}], "]"}], ",", 
     RowBox[{"s", "\[Rule]", "0"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.828763488834259*^9, 3.828763578897264*^9}, {
  3.828764017944064*^9, 3.828764018152987*^9}},
 CellLabel->"In[52]:=",ExpressionUUID->"2a1a257f-5c10-48d6-8ed8-1157684d7c2e"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    SuperscriptBox["s", "2"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", "s"}], ")"}], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "s"}], 
    RowBox[{"x", "-", "s"}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.828763569457604*^9, 3.828763580070436*^9}, 
   3.828764018640061*^9},
 CellLabel->"Out[52]=",ExpressionUUID->"2845ea16-0096-4d29-b6e5-9fb47206de3c"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.828763569457604*^9, 3.828763580070436*^9}, 
   3.828764018698037*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"40e106b5-3140-463c-ba43-a3827946ae34"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 601},
WindowMargins->{{185, Automatic}, {Automatic, 34}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 212, 4, 159, "Title",ExpressionUUID->"8ad34e71-88d7-4f28-8ed7-ebd604030e90"],
Cell[795, 28, 783, 21, 63, "Input",ExpressionUUID->"70e5b736-3567-4dce-a8f3-19388d2de41a"],
Cell[CellGroupData[{
Cell[1603, 53, 157, 3, 69, "Section",ExpressionUUID->"2ecdb72c-3019-40a1-9757-df618becdd4a"],
Cell[1763, 58, 927, 26, 128, "Input",ExpressionUUID->"af14b883-04d6-410b-a251-598c6e1295e9"],
Cell[CellGroupData[{
Cell[2715, 88, 1811, 57, 321, "Input",ExpressionUUID->"c146523d-1aa2-4e85-8562-a1974fb541ce"],
Cell[4529, 147, 680, 21, 64, "Output",ExpressionUUID->"88269c0a-d4be-4726-a637-1a4ec0c08373"],
Cell[5212, 170, 365, 10, 64, "Output",ExpressionUUID->"e627f4ea-749a-434c-89b0-59b03c2f4044"],
Cell[5580, 182, 452, 14, 74, "Output",ExpressionUUID->"74194e32-da86-464b-9c14-df88e4879ec2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6069, 201, 1378, 43, 235, "Input",ExpressionUUID->"fddd0fb5-a8c0-4ff8-9aed-b31b16df0efc"],
Cell[7450, 246, 793, 24, 57, "Output",ExpressionUUID->"be7a2283-f27a-45d6-9726-4dc2f1d43cea"],
Cell[8246, 272, 306, 6, 60, "Output",ExpressionUUID->"25bfacd1-7712-4d6e-8206-6b7143536b22"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8589, 283, 178, 3, 34, "Subsection",ExpressionUUID->"e0fb1f7c-0917-4659-bc3c-b45718e3fda4"],
Cell[CellGroupData[{
Cell[8792, 290, 261, 6, 63, "Input",ExpressionUUID->"d7d238ba-5ed5-440e-9a7f-449159f582f6"],
Cell[9056, 298, 683, 16, 50, "Print",ExpressionUUID->"fad7513d-9742-4d91-9cb9-83c96ef9a646"],
Cell[9742, 316, 184, 3, 39, "Output",ExpressionUUID->"7eac2cd7-81f4-4c9d-995b-977202e3f177"]
}, Open  ]],
Cell[9941, 322, 2214, 52, 189, "Input",ExpressionUUID->"937264ca-8206-468c-a7ce-0bc80347d2f0"],
Cell[CellGroupData[{
Cell[12180, 378, 793, 21, 84, "Input",ExpressionUUID->"2b42fc16-a7af-4bdd-a002-05c09cef5851"],
Cell[12976, 401, 697, 21, 81, "Output",ExpressionUUID->"82137f75-9b27-40dd-b5ee-7d425b715997"],
Cell[13676, 424, 731, 22, 81, "Output",ExpressionUUID->"e6292c60-3202-4094-be0d-2ae129a57326"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14468, 453, 173, 3, 69, "Section",ExpressionUUID->"4ae5ba6b-30ef-4238-ae9b-d3ce1105f331"],
Cell[CellGroupData[{
Cell[14666, 460, 1030, 26, 149, "Input",ExpressionUUID->"2a1a257f-5c10-48d6-8ed8-1157684d7c2e"],
Cell[15699, 488, 449, 13, 65, "Output",ExpressionUUID->"2845ea16-0096-4d29-b6e5-9fb47206de3c"],
Cell[16151, 503, 227, 4, 37, "Output",ExpressionUUID->"40e106b5-3140-463c-ba43-a3827946ae34"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

